@@ -1,3 +1,4 @@
+import copy
 from operator import add
 import types
 
@@ -16,7 +17,13 @@ class Collection(object):
         """
         Create a new task collection/namespace.
 
-        May call with no arguments and use e.g. `.add_task`/`.add_collection` to insert objects, e.g.::
+        `.Collection` offers a set of methods for building a collection of
+        tasks from scratch, plus a convenient constructor wrapping said API.
+
+        **The method approach**
+
+        May initialize with no arguments and use methods (e.g.
+        `.add_task`/`.add_collection`) to insert objects::
 
             c = Collection()
             c.add_task(some_task)
@@ -34,11 +41,16 @@ class Collection(object):
             # (assuming the task objects were actually named the same as the
             # variables we're using :))
 
-        Otherwise, all ``*args`` are expected to be `.Task` or `.Collection`
-        instances which will be passed to `.add_task`/`.add_collection` as
-        appropriate. Module objects are also valid (as they are for
-        `.add_collection`). For example, the below snippet results in the same
-        two task identifiers as the one above::
+        For details, see the API docs for the rest of the class.
+
+        **The constructor approach**
+
+        All ``*args`` given to `.Collection` (besides the optional first 'name'
+        argument) are expected to be `.Task` or `.Collection` instances which
+        will be passed to `.add_task`/`.add_collection` as appropriate. Module
+        objects are also valid (as they are for `.add_collection`). For
+        example, the below snippet results in the same two task identifiers as
+        the one above::
 
             ns = Collection(top_level_task, Collection('docs', doc_task))
 
@@ -56,12 +68,15 @@ class Collection(object):
             ns = Collection()
             ns.add_task(some_other_task, 'top_level_task')
             ns.add_collection(docs, 'docs')
+
+        See individual methods' API docs for details.
         """
         # Initialize
         self.tasks = Lexicon()
         self.collections = Lexicon()
         self.default = None
         self.name = None
+        self._configuration = {}
         # Name if applicable
         args = list(args)
         if args and isinstance(args[0], six.string_types):
@@ -123,7 +138,7 @@ class Collection(object):
         """
         Adds ``Task`` ``task`` to this collection.
 
-        The name the task is bound with is taken, in order, from::
+        The name the task is bound with is taken, in order, from:
 
         * The ``name`` kwarg;
         * If that is not given, the task object's ``name`` attribute;
@@ -243,3 +258,39 @@ class Collection(object):
                     aliases += (coll_name,)
                 ret[self.subtask_name(coll_name, task_name)] = aliases
         return ret
+
+    @property
+    def configuration(self):
+        """
+        Return this collection's configuration options as a dict.
+
+        Child/inner collections' configurations are merged on top of this
+        collection's (so the inner collections will override the parent
+        collection when conflicts arise.) Multiple child collections'
+        configurations are merged in alphabetical order by attached name (thus
+        childs with 'later' names will win.)
+
+        .. note::
+            Merging uses ``copy.deepcopy`` to prevent state bleed.
+        """
+        ret = copy.deepcopy(self._configuration)
+        for key in sorted(self.collections.keys()):
+            ret.update(copy.deepcopy(self.collections[key].configuration))
+        return ret
+
+    def configure(self, options):
+        """
+        Merge ``options`` dict into this collection's `.configuration`.
+
+        Options configured this way will be available to all
+        :doc:`contextualized tasks </concepts/context>`. It is recommended to
+        use unique keys to avoid potential clashes with other config options
+
+        For example, if you were configuring a Sphinx docs build target
+        directory, it's better to use a key like ``'sphinx.target'`` than
+        simply ``'target'``.
+
+        :param options: An object implementing the dictionary protocol.
+        :returns: ``None``.
+        """
+        self._configuration.update(options)
