@@ -270,3 +270,42 @@ class Collection_(Spec):
             names = self.c.task_names
             eq_(names['top_level'], ['othertop'])
             eq_(names['sub.sub_task'], ['sub.othersub', 'sub'])
+
+    class configuration:
+        "Configuration methods"
+        def setup(self):
+            self.c = Collection()
+
+        def basic_set_and_get(self):
+            self.c.configure({'foo': 'bar'})
+            eq_(self.c.configuration, {'foo': 'bar'})
+
+        def configure_performs_merging(self):
+            self.c.configure({'foo': 'bar'})
+            eq_(self.c.configuration['foo'], 'bar')
+            self.c.configure({'biz': 'baz'})
+            eq_(set(self.c.configuration.keys()), set(['foo', 'biz']))
+
+        def access_returns_dict(self):
+            eq_(self.c.configuration, {})
+            self.c.configure({'foo': 'bar'})
+            eq_(self.c.configuration, {'foo': 'bar'})
+
+        def access_merges_from_subcollections(self):
+            inner = Collection('inner')
+            inner.configure({'foo': 'bar'})
+            outer = Collection()
+            outer.configure({'biz': 'baz'})
+            # With no inner collection
+            eq_(set(outer.configuration.keys()), set(['biz']))
+            # With inner collection
+            outer.add_collection(inner)
+            eq_(set(outer.configuration.keys()), set(['foo', 'biz']))
+
+        def access_merges_siblings_in_alpha_order(self):
+            a = Collection('a')
+            a.configure({'mysetting': 'a'})
+            b = Collection('b')
+            b.configure({'mysetting': 'b'})
+            parent = Collection(b, a) # Ensuring add order doesn't matter. Eh.
+            eq_(parent.configuration['mysetting'], 'b')
