@@ -225,6 +225,10 @@ class Context_(Spec):
                 ("-p [STRING], --optval[=STRING]", "")
             )
 
+        def underscored_args(self):
+            c = Context(args=(Argument('i_have_underscores', help='yup'),))
+            eq_(c.help_for('--i-have-underscores'), ('--i-have-underscores=STRING', 'yup'))
+
     class help_tuples:
         def returns_list_of_help_tuples(self):
             # Walks own list of flags/args, ensures resulting map to help_for()
